"""
Analysis specific job handler for B -> D(*(*)) tau nu analysis.

Performs run time sampling and job submission for specified
configuration files.

Felix Metzner 2018
"""

import os
import b2luigi as luigi
import analysistools.batch_tools.tasks as analysis_tasks
import analysistools.batch_tools.job_handler as handler

config_base_dir = '/home/belle2/metzner/RDStar/rdstar/configs/'

config_production_dir = 'prod_11thJan2020_stream0'
# config_production_dir = 'prod_11thJan2020_stream1'

batch_configs = [
    # os.path.join(config_base_dir, 'batch_config.json'),  # Test configuration
    # os.path.join(config_base_dir, 'test_batch_config.json'),  # Larger Test configuration
    # os.path.join(config_base_dir, config_production_dir, 'fsp_batch_config.json'),  # Final State Particles Study configuration
    # os.path.join(config_base_dir, config_production_dir, 'skim_study_batch_config.json'),  # Skim Study configuration
    # os.path.join(config_base_dir, config_production_dir, 'dmeson_batch_config.json'),  # D Meson Study configuration
    os.path.join(config_base_dir, config_production_dir, 'charged_batch_config.json'),
    os.path.join(config_base_dir, config_production_dir, 'mixed_batch_config.json'),
    os.path.join(config_base_dir, config_production_dir, 'uds_batch_config.json'),
    os.path.join(config_base_dir, config_production_dir, 'charm_batch_config.json'),
    os.path.join(config_base_dir, config_production_dir, 'd_starstar_batch_config.json'),
    os.path.join(config_base_dir, config_production_dir, 'dstst_batch_config.json'),
    os.path.join(config_base_dir, config_production_dir, 'dstst_eff_batch_config.json'),
    os.path.join(config_base_dir, config_production_dir, 'dstst_e_charged_eff_batch_config.json'),
    os.path.join(config_base_dir, config_production_dir, 'dstst_mu_charged_eff_batch_config.json'),
    os.path.join(config_base_dir, config_production_dir, 'gap_batch_config.json'),
    os.path.join(config_base_dir, config_production_dir, 'signal_batch_config.json'),
    os.path.join(config_base_dir, config_production_dir, 'rare_batch_config.json'),
    os.path.join(config_base_dir, config_production_dir, 'rare_ulnumixed_batch_config.json'),
    os.path.join(config_base_dir, config_production_dir, 'special_batch_config.json'),
    os.path.join(config_base_dir, config_production_dir, 'data_batch_config.json'),
]

# Using charged batch config as base for run time sampling:
rts_batch_config = os.path.join(config_base_dir, config_production_dir, 'charged_batch_config.json')


class JobHandlerTask(luigi.WrapperTask):
    def get_task_file_dir(self):
        batch_config = handler.load_json_config(batch_configs[0], hint="Loading batch config in JobHandlerTask")
        global_config = handler.load_json_config(
            batch_config["global_config"],
            hint="Loading global config in JobHandlerTask"
        )
        os.makedirs(global_config["target_directory"], exist_ok=True)
        return os.path.join(global_config["target_directory"], f"{self.get_task_family()}_{config_production_dir}")

    def get_log_file_dir(self):
        return self.get_task_file_dir()

    def requires(self):
        # yield handler.RunTimeSamplingMaster(batch_config_file=rts_batch_config, sample_chunks=10, chunk_size=5000)

        for batch_config in batch_configs:
            yield analysis_tasks.Master(batch_config_file=batch_config)


if __name__ == '__main__':
    num_workers = 10000
    print(f"Starting to process events with\n"
          f"    workers = {num_workers}\n"
          f"    batch configuration files:")
    for config in batch_configs:
        print(config)

    luigi.process(JobHandlerTask(), workers=num_workers)
