# Belle MC production for the R(D^(*)) analysis

This package contains a python wrapper and decay files for private signal MC production using the `basf` software on the `kekcc`.
 
 
## Event Generation
 1. Make sure you are running `bash` (required for `basf`) and all required scripts are executable, including `runRvtgen` and the `.csh` files in the `evtgen` directory.
 2. Setup the `basf` environment by executing the following command
 ```bash
 source ./setup_basf.sh
 ```
 3. Run the script with
    ```bash
    ./mc_generation.py -t DECAY_TYPE -n TOTAL_NUMBER_OF_EVTS -j MAX_NUMBER_OF_EVTS_PER_JOB -o PATH_TO_OUPUT_DIRECTORY
    ```
    where `TOTAL_NUMBER_OF_EVTS` is the number of events produced per decay file for this decay type.
    You can run the script with `./mc_generation.py -h` to get an overview of the allowed command line arguments. Available decay types are:
    * `Dlnu`: B->Dlnu decays
    * `Dstlnu`: B->D*lnu decays
    * `Dststlnu`: B->D**lnu decays  
     
You can find the `.dec` files of these events in the `dec_files/` directory. If you want to add new `.dec` files, create 
a directory in `dec_files/` and add the decay types to the `dec_file_dirs` in `mc_generation.py` and `mc_simulation.py`.

After the evtgen jobs ran through one can tidy up with the command

```bash
./mc_generation.py -t DECAY_TYPE -n TOTAL_NUMBER_OF_EVTS -j MAX_NUMBER_OF_EVTS_PER_JOB -o PATH_TO_OUPUT_DIRECTORY --clean
```

This command will remove the various job scripts, which were
created during the MC generation, as well as the copied decay files.

### Event Generation Summary
You can check if the right number of events was produced by evtgen by running the `makeSummaryEvtgen` script in
the `evtgen` directory:
```bash
./evtgen/makeSummaryEvtgen -MC <PATH_TO_OUPUT_DIRECTORY>/evtgen/log/*/evtgen*
```
where `PATH_TO_OUPUT_DIRECTORY` is the same directory as used in the call of the `mc_generation.py` script.
The sum of events produced should correspond to the total number of events you requested. 
    
## Event Simulation
 1. Again all relevant scripts must be executable: `mc_simulation.py` and the `.csh` scripts in the `gsim` directory.
 2. Run the `mc_simulation.py` script with the following parameters:
    * `-t`: Decay type, e.g. `-t Dlnu`
    * `-i`: Input directory, e.g. `-i PATH_TO_OUPUT_DIRECTORY`, where `PATH_TO_OUPUT_DIRECTORY` is the path to the directory specified for the event generation
    
The `mdst` files will be placed in `PATH_TO_OUPUT_DIRECTORY/gsim/mdst/`.

Also here, you can tidy up by running `mc_simulation.py -t x -i x --clean`, which will
remove all job scripts in the `gsim` directory. Again, this must be done manually after
all gsim jobs completed successfully.

### Event Simulation Summary
To get the number of actually produced events, you should run the script `makeSummaryGsim`
which can be found in the `gsim` directory:
```bash
./makeSummaryGsim -MC <PATH_TO_OUPUT_DIRECTORY>gsim/log/*/evtgen_exp_*-?.log
```
Here `log/*/evtgen_exp_*-?.log` should parse **all** `.log` files and omit the `generror.log` and `genlog.log` files.

This report will generate a count of the number of events generated. 
You can also use `log/<decay_type>/evtgen_exp_*-?.log` to get the number of events produced for the specified decay type.

This check will also show you which jobs failed. You can rerun them by looking at the respective log files
and rerun them via the following command executed in the `gsim` directory:
```bash
bsub -q l -e <PATH_TO_OUPUT_DIRECTORY>/gsim/log/<data_type>/evtgen_exp_<...>error.log -o <PATH_TO_OUPUT_DIRECTORY>/gsim/log/<data_type>/evtgen_exp_<...>log.log ./rec.csh <PATH_TO_OUPUT_DIRECTORY>/evtgen/gen/<data_type>/evtgen_exp_<...>.gen <exp_num> <data_type> <PATH_TO_OUPUT_DIRECTORY>
```
where some job specific strings have to be adapted.
These can be extracted from the respective log files.

You can resubmit failed Gsim jobs using the `resubmit_gsim.py` script (in the `gsim` folder). For that pipe the output from `./makeSummaryGsim -MC <PATH_TO_OUPUT_DIRECTORY>gsim/log/*/evtgen_exp_*-?.log` into
a file. Faile jobs are then automatically resubmitted with
```bash
./resubmit_gsim -i <SUMMARY_FILE.txt>
```
