#!/usr/bin/python

import argparse
import subprocess
import os
import sys
import shutil
import socket

def check_host():
    """
    Checks if scripts are executed on the KEKCC. If not, the
    execution of the script is terminated.
    """
    if "cc.kek.jp" not in socket.gethostname():
        sys.exit("This script can only be executet on kekcc. Terminating!")


def parse_command_line_args():
    parser = argparse.ArgumentParser(
        description="This script resubmits faile reconstruction jobs unsing input from makeGsimsummary."
    )
    parser.add_argument("-i", action="store", dest="summary_file", type=str, required=True)
    parsed_args = parser.parse_args()

    return parsed_args


def extract_failed_job_info(summary_file):

    with open(summary_file, "r") as file:
        failed_jobs_lines = list()

        for line in file:
            if line.startswith("WARNING"):
                failed_jobs_lines.append(line.rstrip("!\n").lstrip("'WARNING: NO output events number found in "))

        failed_job_info_dict_list = list()

        for line in failed_jobs_lines:
            source_dir = line.split("/gsim")[0]
            decay = line.split("log/")[1].split("/")[0]
            mdst_file = line.split("log/")[1].split("/")[1].split(".")[0] + ".gen"
            evtgen_mdst_path = os.path.join(source_dir, "evtgen", "gen", decay, mdst_file)
            exp_no = line.split("log/")[1].split("/")[1].split(".")[0].split("_")[2]

            failed_job_info_dict_list.append(
                {"source_dir": source_dir,
                 "decay": decay,
                 "mdst_file": mdst_file,
                 "evtgen_mdst_path": evtgen_mdst_path,
                 "exp_no": exp_no}
            )

        return failed_job_info_dict_list


def resubmit_jobs(job_info_dict):
    file_name = job_info_dict["mdst_file"].split(".")[0]
    log_dir = os.path.join(job_info_dict["source_dir"], "gsim", "log", job_info_dict["decay"])
    error_log = os.path.join(log_dir, job_info_dict["mdst_file"]) + "error.log"
    log_log = os.path.join(log_dir, job_info_dict["mdst_file"]) + "log.log"
    log = os.path.join(log_dir, file_name) + ".log"

    mdst = os.path.join(job_info_dict["source_dir"], "gsim", "mdst", job_info_dict["decay"], file_name + ".mdst")
    hbook = os.path.join(job_info_dict["source_dir"], "gsim", "hbook", job_info_dict["decay"], file_name + ".hbook")

    for f in [error_log, log_log, log, mdst, hbook]:
        try:
            os.remove(f)
        except OSError:
            continue

    command = ["bsub", "-q", "l", "-eo", error_log, "-oo", log_log,
               "./rec.csh", job_info_dict["evtgen_mdst_path"], job_info_dict["exp_no"], job_info_dict["decay"],
               job_info_dict["source_dir"]]
    print "Resubmitting Gsim job with the following commands"
    # print command
    subprocess.check_call(command)


if __name__=="__main__":
    check_host()

    args = parse_command_line_args()

    summary_file = args.summary_file

    for info in extract_failed_job_info(summary_file):
        resubmit_jobs(info)


