import os

import b2luigi
from b2luigi.basf2_helper import Basf2PathTask

import pandas as pd
import root_pandas

from rdstar.mc_reweighting.BtoDststlnu.generate_events import get_events_from_b2bii
from rdstar.mc_reweighting.BtoDststlnu.reweighting_variables import calculate_reweighting_variables


class B2BIIConversionTask(Basf2PathTask):
    input_file = b2luigi.Parameter(hashed=True)
    queue = 's'

    def output(self):
        yield self.add_to_output("events.root")

    def create_path(self):
        return get_events_from_b2bii(self.input_file, self.get_output_file_name("events.root"))


class MergeDststTypeTask(b2luigi.Task):

    decay_type = b2luigi.Parameter()
    queue = "l"

    def output(self):
        yield self.add_to_output("converted.h5")

    def run(self):
        input_data = self.get_input_file_names("events.root")
        df = root_pandas.read_root(input_data)
        df.to_hdf(self.get_output_file_name("converted.h5"), key="df", mode="w")

    def requires(self):

        path_to_ntuples = '/group/belle2/users/welsch/ntuples/b_sl_dstst_updated_mass/nevt_2500k/gsim/mdst/'
        dirs = [
            f"Bminus_{self.decay_type}_e/",
            f"Bminus_{self.decay_type}_mu/",
            f"Bzero_{self.decay_type}_e/",
            f"Bzero_{self.decay_type}_mu/",
        ]

        input_files = list()

        for dir in dirs:
            dir = path_to_ntuples + dir
            mdst_files = [dir + file for file in os.listdir(dir)]
            input_files.extend(mdst_files)

        for input_file in input_files:
            yield self.clone(B2BIIConversionTask, input_file=input_file)


@b2luigi.requires(MergeDststTypeTask)
class ReweightingVariablesCalculationTaks(b2luigi.Task):
    """
    This task takes the combined dataframes and calculates the required variables
    for the reweighting defined in `reweighting_variables.py`.
    """
    # def requries(self):
    #     yield self.clone(
    #         B2BIIConversionTask
    #     )
    queue = 'l'

    def output(self):
        yield self.add_to_output("reweighting_variables.h5")

    def run(self):
        input_data = self.get_input_file_names("converted.h5")[0]

        # dfs = list()
        # for input in input_data:
        #     dfs.append(pd.read_hdf(input, "df"))

        df = pd.read_hdf(input_data, "df")
        new_df = calculate_reweighting_variables(df)
        new_df.to_hdf(
            self.get_output_file_name('reweighting_variables.h5'),
            key="df",
            mode="w"
        )


class MainTask(b2luigi.Task):

    def requires(self):
        types = [
            "D0star",
            "D1",
            "D2star",
            "Dprime1",
        ]

        for t in types:
            yield self.clone(
                ReweightingVariablesCalculationTaks,
                decay_type=t
            )


if __name__ == "__main__":
    # b2luigi.process(B2BIIConversionTask(decay_type="D0star"))
    b2luigi.process(MainTask(), workers=1000)