"""
This script merges all dataframes of a common Dstst decay type with different
decay model parameters into one dataframe and saves it. A new column specifying
the decay model is added to the dataframe.
"""
import os

import pandas as pd


LUIGI_RESULT_DIR = "/storage/9/welsch/reweighting/results/n_events=1000000/"
OUTPUT_PATH = "/storage/9/welsch/reweighting/llsw_data"

DSTS_TYPES = [
    "Done",
    "Dprimeone",
    "Dtwostar",
    "Dzerostar"
]

LLSW_VARIATIONS = [
    "nominal",
    "up_0",
    "up_1",
    "up_2",
    "up_3",
    "down_0",
    "down_1",
    "down_2",
    "down_3",
]

print("Merging LLSW reweighting ntuples into a common dataframe:")

if not os.path.exists(OUTPUT_PATH):
    print(f"Ouput path {OUTPUT_PATH} does not exist.\n"
          f"Creating new directory.")
    os.makedirs(OUTPUT_PATH)

for dstst_type in DSTS_TYPES:
    print(f"\tProccesing D** type: {dstst_type}")
    llsw_dfs = dict()

    for llsw_variation in LLSW_VARIATIONS:

        if llsw_variation == "nominal":
            variation_dir = f"model_variation=LLSW_nominal"
        else:
            variation_dir = f"model_variation=LLSW_variation_{llsw_variation}"

        dstst_channel_dir = f"decay_channel={dstst_type}"
        file = "reweighting_vars.h5"

        path_to_file = os.path.join(LUIGI_RESULT_DIR, variation_dir, dstst_channel_dir, file)
        print(f"\t\tLoading variation: {llsw_variation} from file {path_to_file}")
        try:
            llsw_dfs[llsw_variation] = pd.read_hdf(
                path_to_file,
                "df"
            )
        except FileNotFoundError:
            continue

        llsw_dfs[llsw_variation]["variation"] = llsw_variation

    merged = pd.concat([df for df in llsw_dfs.values()])

    merged.to_hdf(
        os.path.join(OUTPUT_PATH, dstst_type+".h5"),
        key="df",
        mode="w"
    )


