"""
Collection of data samples used in the RDStar analysis

Felix Metzner 2019
"""

from typing import Dict, List

from rdstar.offline_analysis import rdstar_sample_weights
from analysistools.batch_tools.file_handler import Belle_list_types


__all__ = [
    "data_type_combinations",
    "recorded_data_samples",
    "main_sample_keys",
    "main_samples",
    "efficiency_samples",
    "unused_samples"
]


private_data_types = list(rdstar_sample_weights.signal_mc_bfs.keys())

data_type_combinations = {  # type: Dict[str, List[str]]
    "Charged": ["Charged"],
    "Mixed": ["Mixed"],
    "UDS": ["UDS"],
    "Charm": ["Charm"],
    "Special": [c for c in Belle_list_types if "psi" not in c],
    "SpecialPsi": [c for c in Belle_list_types if "psi" in c],
    "Dss": [c for c in private_data_types if c.startswith("B") and not c.endswith("Test") and not c.endswith("Eff")],
    "Gap": [c for c in private_data_types if c.startswith("Gap")],
    "SignalEff": [c for c in private_data_types if c.startswith("D")],
    "DssSignalEff": [c for c in private_data_types if c.startswith("B") and c.endswith("Test") and "ChargedP" not in c],
    "DssPiSignalEff": [c for c in private_data_types if c.startswith("B") and c.endswith("Eff") and "Charged" not in c],
    "DssPiPlusSignalEff": [c for c in private_data_types if c.startswith("B") and c.endswith("ChargedPiEff")],
    "DataY4S": ["DataY4S"],
    "DataContinuum": ["DataContinuum"]
}

recorded_data_samples = [  # type: List[str]
    *data_type_combinations["DataY4S"],
    *data_type_combinations["DataContinuum"],
]

main_sample_keys = [  # type: List[str]
    "Charged",
    "Mixed",
    "UDS",
    "Charm",
    "Special",
    "Dss",
    "Gap",
]

main_samples = [  # type: List[str]
    *data_type_combinations["Charged"],
    *data_type_combinations["Mixed"],
    *data_type_combinations["UDS"],
    *data_type_combinations["Charm"],
    *data_type_combinations["Special"],
    *data_type_combinations["Dss"],
    *data_type_combinations["Gap"],
]

efficiency_samples = [  # type: List[str]
    *data_type_combinations["SignalEff"],
    *data_type_combinations["DssSignalEff"],
    *data_type_combinations["DssPiSignalEff"],
    *data_type_combinations["DssPiPlusSignalEff"]
]

unused_samples = [  # type: List[str]
    *data_type_combinations["SpecialPsi"],
]

all_samples = recorded_data_samples + main_samples + efficiency_samples + unused_samples  # type: List[str]
assert len([s for v in data_type_combinations.values() for s in v]) == len(all_samples)
