"""
This module defines the final state particles considered for the analysis.

For this analysis the ones already prepared in final_state_particles_utils
are taken.

Felix Metzner 2018
"""

import copy

from analysistools.processing.final_state_particles_utils import FinalStateParticle, FSRCorrectionSettings
from analysistools.processing.final_state_particles_utils import fsp_collection as original_fsp_collection, electron

electron_fsr_correction_settings = FSRCorrectionSettings(
    fsr_gamma_list_name="gamma:fsp",
    angle_threshold=2.0,
    energy_threshold=0.4,
    theta_threshold=1.0,
    momentum_factor=0.4,
    method='centeredCone',
    take_all_gamma=True,
    write_out=False
)
electron_with_fsrc = copy.deepcopy(electron)
electron_with_fsrc.electron_fsr_correction = electron_fsr_correction_settings

e_neutrino = FinalStateParticle(
    label='nu_e',
    particlelist='nu_e:mc',
    origin='mc',
    cuts=[
        'dr < 2',
        'abs(dz) < 4'
    ]
)

mu_neutrino = FinalStateParticle(
    label='nu_mu',
    particlelist='nu_mu:mc',
    origin='mc',
    cuts=[
        'dr < 2',
        'abs(dz) < 4'
    ]
)

tau_neutrino = FinalStateParticle(
    label='nu_tau',
    particlelist='nu_tau:mc',
    origin='mc',
    cuts=[
        'dr < 2',
        'abs(dz) < 4'
    ]
)

fsp_collection = copy.deepcopy(original_fsp_collection)

#fsp_collection.remove_fsps(keys=['tau'])
fsp_collection.remove_fsps(keys=['electron'])
fsp_collection.add_fsps(electron=electron_with_fsrc)

fsp_collection.add_fsps(e_neutrino=e_neutrino)
fsp_collection.add_fsps(mu_neutrino=mu_neutrino)
fsp_collection.add_fsps(tau_neutrino=tau_neutrino)

if __name__ == '__main__':
    print(fsp_collection)
